pub enum DeviceError {
Unsupported,
Sample(String),
Host(String),
}Expand description
Error returned by stream-device providers and sessions.
Variants
Unsupported
The selected provider does not support opening or using a device.
Sample(String)
A sample expression was malformed for the requested sample kind.
Host(String)
A provider or session failed for a host-specific reason.