pub enum DeviceSiteLocality {
EdgeLocal,
HostLocal,
Remote,
}Expand description
Placement locality advertised by a device site.
Variants
EdgeLocal
Device adapter runs at the device or edge boundary.
HostLocal
Site runs on the host but not at the device edge.
Remote
Site crosses a remote transport boundary.