pub enum ReversalPolicy {
Irreversible,
Effect(Symbol),
}Expand description
Policy describing whether and how an effect can be reversed.
Variants
Irreversible
No reversal exists.
Effect(Symbol)
Invoke the named registered effect to reverse this effect.