pub fn music_effect_registry() -> DeviceResult<EffectRegistry>Expand description
Registry containing every and only the reviewed music effects.
pub fn music_effect_registry() -> DeviceResult<EffectRegistry>Registry containing every and only the reviewed music effects.