DeviceCatalog

Struct DeviceCatalog 

pub struct DeviceCatalog { /* private fields */ }
Registry of stream-device providers.

Implementations

Source

impl DeviceCatalog

pub fn new() -> Self

Builds an empty device catalog.

pub fn default_modeled() -> Self

Builds a catalog with deterministic modeled MIDI and audio providers.

pub fn with_registry_audio_devices(registry: &Registry) -> Self

Builds a modeled catalog plus audio devices exported by loaded libs.

pub fn register(&mut self, provider: Box<dyn DeviceProvider>)

Registers a device provider.

pub fn register_provider_sites(&mut self, router: &AudioRouter)

Adds a snapshot of the audio sites currently registered by a provider.

pub fn register_registry_audio_devices(&mut self, registry: &Registry)

Adds audio-device records currently owned by loaded registry libs.

pub fn enumerate(&self) -> Result<Vec<DeviceRecord>>

Enumerates every registered provider.

pub fn open(&self, id: &Symbol) -> Result<Box<dyn StreamEvalSite>>

Opens a cataloged stream evaluation site by device id.

pub fn open_live(&self, id: &Symbol) -> Result<MidiLiveEvalSite>

Opens a cataloged MIDI device as a live MIDI evaluation site.

pub fn enumerate_midi(&self) -> Result<Vec<DeviceRecord>>

Enumerates MIDI device rows.

pub fn enumerate_audio(&self) -> Result<Vec<DeviceRecord>>

Enumerates audio device rows.