pub struct DeviceSite {
pub symbol: Symbol,
pub profile: DeviceProfile,
pub surface_codec_id: Symbol,
pub locality: DeviceSiteLocality,
}Expand description
Export-record-style descriptor for a stream device site.
Fields
symbol: SymbolStable site symbol exported by the provider.
profile: DeviceProfileDevice profile carried by this site export.
surface_codec_id: SymbolSurface codec used to encode device samples and commands.
locality: DeviceSiteLocalityLocality used by placement validation.
Implementations
Sourceimpl DeviceSite
impl DeviceSite
Sourcepub fn new(
symbol: Symbol,
profile: DeviceProfile,
surface_codec_id: Symbol,
locality: DeviceSiteLocality,
) -> Self
pub fn new( symbol: Symbol, profile: DeviceProfile, surface_codec_id: Symbol, locality: DeviceSiteLocality, ) -> Self
Builds a device site descriptor.
Sourcepub fn edge_local(
symbol: Symbol,
profile: DeviceProfile,
surface_codec_id: Symbol,
) -> Self
pub fn edge_local( symbol: Symbol, profile: DeviceProfile, surface_codec_id: Symbol, ) -> Self
Builds a device or edge-local site descriptor.
Sourcepub fn host_local(
symbol: Symbol,
profile: DeviceProfile,
surface_codec_id: Symbol,
) -> Self
pub fn host_local( symbol: Symbol, profile: DeviceProfile, surface_codec_id: Symbol, ) -> Self
Builds a host-local site descriptor.
Sourcepub fn remote(
symbol: Symbol,
profile: DeviceProfile,
surface_codec_id: Symbol,
) -> Self
pub fn remote( symbol: Symbol, profile: DeviceProfile, surface_codec_id: Symbol, ) -> Self
Builds a remote site descriptor.
Sourcepub fn is_edge_local(&self) -> bool
pub fn is_edge_local(&self) -> bool
Returns whether this site is local enough for a latency-critical adapter.
Sourcepub fn require_edge_local(&self) -> DeviceResult<()>
pub fn require_edge_local(&self) -> DeviceResult<()>
Checks that this site is local enough for a latency-critical adapter.