pub struct HostBackendRegistry { /* private fields */ }Expand description
Deterministic registry of host stream backends.
Implementations
Sourceimpl HostBackendRegistry
impl HostBackendRegistry
Sourcepub fn register<B>(&mut self, backend: B) -> Result<()>where
B: HostBackend + 'static,
pub fn register<B>(&mut self, backend: B) -> Result<()>where
B: HostBackend + 'static,
Registers a backend by its stable backend id.
Sourcepub fn register_arc(&mut self, backend: Arc<dyn HostBackend>) -> Result<()>
pub fn register_arc(&mut self, backend: Arc<dyn HostBackend>) -> Result<()>
Registers an already shared backend.
Sourcepub fn backend(&self, id: &Symbol) -> Option<Arc<dyn HostBackend>>
pub fn backend(&self, id: &Symbol) -> Option<Arc<dyn HostBackend>>
Returns a registered backend by id.
Sourcepub fn enumerate(&self) -> Result<Vec<HostDeviceInventory>>
pub fn enumerate(&self) -> Result<Vec<HostDeviceInventory>>
Enumerates every registered backend.
Sourcepub fn open(&self, request: HostStreamConfigRequest) -> Result<HostOpenStream>
pub fn open(&self, request: HostStreamConfigRequest) -> Result<HostOpenStream>
Opens a stream using the backend named in the request.
Sourcepub fn card_exprs(&self) -> Result<Vec<Expr>>
pub fn card_exprs(&self) -> Result<Vec<Expr>>
Emits backend, device, and port browse card expressions.
Sourcepub fn missing_capability_card(
&self,
backend: &Symbol,
capability: HostBackendCapability,
) -> Expr
pub fn missing_capability_card( &self, backend: &Symbol, capability: HostBackendCapability, ) -> Expr
Emits a browse card for a missing backend capability.