pub struct HostOpenPlan { /* private fields */ }Expand description
Resolved plan describing how a device would be opened.
Names the backend, device, the effect kinds the open performs, and the capabilities the open requires.
Implementations
Sourceimpl HostOpenPlan
impl HostOpenPlan
Sourcepub fn new(
backend: Symbol,
device: Symbol,
effect_kinds: Vec<Symbol>,
requires: Vec<CapabilityName>,
) -> Self
pub fn new( backend: Symbol, device: Symbol, effect_kinds: Vec<Symbol>, requires: Vec<CapabilityName>, ) -> Self
Builds an open plan from resolved backend, device, effects, and required capabilities.
Sourcepub fn effect_kinds(&self) -> &[Symbol]
pub fn effect_kinds(&self) -> &[Symbol]
Returns the effect kinds the open performs.
Sourcepub fn requires(&self) -> &[CapabilityName]
pub fn requires(&self) -> &[CapabilityName]
Returns the capabilities the open requires.