HostOpenStream

Struct HostOpenStream 

pub struct HostOpenStream { /* private fields */ }
Open stream plus host-side callback queue.

Implementations

Source

impl HostOpenStream

pub fn new(config: HostStreamConfig) -> Self

Creates an opened host stream backed by a push stream value.

pub fn new_with_driver( config: HostStreamConfig, driver: Rc<dyn HostStreamDriver>, ) -> Self

Creates an opened host stream with an attached external driver.

pub fn try_new_with_driver( config: HostStreamConfig, build_driver: impl FnOnce(HostCallbackQueue) -> Result<Rc<dyn HostStreamDriver>>, ) -> Result<Self>

Creates an opened host stream by building its driver from the callback queue that will be stored on the stream.

pub fn new_realtime_local_audio(config: HostStreamConfig) -> Result<Self>

Creates a realtime local audio stream after validating callback limits.

pub fn new_realtime_local_audio_with_driver( config: HostStreamConfig, driver: Rc<dyn HostStreamDriver>, ) -> Result<Self>

Creates a realtime local audio stream with an attached external driver.

pub fn try_new_realtime_local_audio_with_driver( config: HostStreamConfig, build_driver: impl FnOnce(HostCallbackQueue) -> Result<Rc<dyn HostStreamDriver>>, ) -> Result<Self>

Creates a realtime local audio stream by building its driver from the stored callback queue.

pub fn new_lan_midi_control(config: HostStreamConfig) -> Result<Self>

Creates a LAN MIDI/control stream after validating media and clock shape.

pub fn new_lan_buffered_audio_preview(config: HostStreamConfig) -> Result<Self>

Creates a LAN buffered audio preview stream after validating media shape.

pub fn config(&self) -> &HostStreamConfig

Returns the accepted stream configuration.

pub fn queue(&self) -> &HostCallbackQueue

Returns the callback queue used by host callbacks or deterministic fakes.

pub fn stream(&self) -> Arc<StreamValue>

Returns the stream value consumed by graph/runtime code.

pub fn close(&self) -> Result<()>

Closes the host callback queue.

pub fn cancel(&self) -> Result<()>

Cancels the callback queue and drops buffered packets.