pub struct HostStreamConfigRequest { /* private fields */ }Expand description
Request supplied to a host backend when opening a stream.
Implementations
Sourceimpl HostStreamConfigRequest
impl HostStreamConfigRequest
Sourcepub fn new(
backend: Symbol,
device: Symbol,
media: StreamMedia,
direction: HostDirection,
buffer: BufferPolicy,
) -> Self
pub fn new( backend: Symbol, device: Symbol, media: StreamMedia, direction: HostDirection, buffer: BufferPolicy, ) -> Self
Builds an open request for device on backend with a server-frame
clock and reconnect disabled.
Sourcepub fn with_clock(self, clock: Symbol) -> Self
pub fn with_clock(self, clock: Symbol) -> Self
Overrides the requested clock-domain symbol.
Sourcepub fn with_reconnect(self, reconnect: HostReconnectPolicy) -> Self
pub fn with_reconnect(self, reconnect: HostReconnectPolicy) -> Self
Overrides the requested reconnect policy.
Sourcepub fn media(&self) -> StreamMedia
pub fn media(&self) -> StreamMedia
Returns the requested stream media.
Sourcepub fn direction(&self) -> HostDirection
pub fn direction(&self) -> HostDirection
Returns the requested stream direction.
Sourcepub fn buffer(&self) -> &BufferPolicy
pub fn buffer(&self) -> &BufferPolicy
Returns the requested buffer policy.
Sourcepub fn reconnect(&self) -> &HostReconnectPolicy
pub fn reconnect(&self) -> &HostReconnectPolicy
Returns the requested reconnect policy.