MidiLiveEvalSite

Struct MidiLiveEvalSite 

pub struct MidiLiveEvalSite { /* private fields */ }
Live MIDI evaluation site opened from a cataloged device record.

Implementations

Source

impl MidiLiveEvalSite

pub fn from_eval_site( id: &Symbol, site: Box<dyn StreamEvalSite>, ) -> Result<Self>

Wraps an opened catalog site in a live MIDI session.

pub fn source_mut(&mut self) -> &mut dyn MidiSource<Err = Infallible>

Returns the live MIDI source side.

pub fn sink_mut(&mut self) -> Option<&mut dyn MidiSink<Err = Infallible>>

Returns the live MIDI sink side when this site supports output.