pub struct RtpMidiPort { /* private fields */ }Expand description
An opened RTP-MIDI source port and its callback queue.
Implementations
Sourceimpl RtpMidiPort
impl RtpMidiPort
Sourcepub fn spec(&self) -> &HostDeviceSpec
pub fn spec(&self) -> &HostDeviceSpec
Returns the device spec backing this port.
Sourcepub fn queue(&self) -> &HostCallbackQueue
pub fn queue(&self) -> &HostCallbackQueue
Returns the callback queue host callbacks enqueue into.
Sourcepub fn stream(&self) -> Arc<StreamValue>
pub fn stream(&self) -> Arc<StreamValue>
Returns a shared handle to the underlying stream value.
Sourcepub fn receive_packet_from_callback(&self, packet: MidiPacket) -> Result<()>
pub fn receive_packet_from_callback(&self, packet: MidiPacket) -> Result<()>
Enqueues a MIDI packet received by a host callback.
Sourcepub fn receive_envelope_from_callback(
&self,
sequence: u64,
packet: MidiPacket,
) -> Result<StreamEnvelope>
pub fn receive_envelope_from_callback( &self, sequence: u64, packet: MidiPacket, ) -> Result<StreamEnvelope>
Enqueues a MIDI packet and returns the stream envelope describing it under the LAN MIDI/control transport profile.