AudioSite

Trait AudioSite 

pub trait AudioSite: Send + Sync {
    // Required methods
    fn key(&self) -> &AudioSiteKey;
    fn card(&self) -> &AudioDeviceCard;
    fn open(&self, request: HostStreamConfigRequest) -> Result<HostOpenStream>;
}
Runtime-openable audio placement target.

An audio site owns stable descriptive metadata and delegates stream opening to the backend implementation selected for that site.

Required Methods

fn key(&self) -> &AudioSiteKey

Returns the stable key used to register and route this site.

fn card(&self) -> &AudioDeviceCard

Returns the browseable device card for this site.

fn open(&self, request: HostStreamConfigRequest) -> Result<HostOpenStream>

Opens a host stream for this site using the supplied stream request.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors