HostDirection

Enum HostDirection 

pub enum HostDirection {
    Input,
    Output,
    Duplex,
}
Direction of a host stream relative to the device.

Variants



Input

Device delivers data into the runtime (a source).



Output

Device receives data from the runtime (a sink).



Duplex

Device both delivers and receives data.

Implementations

Source

impl HostDirection

pub fn stream_direction(self) -> StreamDirection

Maps this host direction to the core StreamDirection.

pub fn symbol(self) -> Symbol

Returns the stable qualified symbol naming this direction.

pub fn effect_kind(self) -> Symbol

Returns the effect kind an open in this direction performs (device read for input, device write for output or duplex).