pub struct AudioProviderHost<'a> { /* private fields */ }Expand description
Host that loads audio providers through the kernel loader and registers sites.
Implementations
Sourceimpl<'a> AudioProviderHost<'a>
impl<'a> AudioProviderHost<'a>
Sourcepub fn new(cx: &'a mut Cx, loaders: &'a LoaderRegistry) -> Self
pub fn new(cx: &'a mut Cx, loaders: &'a LoaderRegistry) -> Self
Builds a provider host over a context and loader registry.
Sourcepub fn with_entry(self, provider: Symbol, entry: AudioProviderEntry) -> Self
pub fn with_entry(self, provider: Symbol, entry: AudioProviderEntry) -> Self
Adds a provider entry, builder-style.