pub struct HostOpenPlan { /* private fields */ }Expand description
Resolved plan describing how a device would be opened.
Names the backend, device, the effect kind the open performs, and the capabilities the open requires.
Implementations
Sourceimpl HostOpenPlan
impl HostOpenPlan
Sourcepub fn effect_kind(&self) -> &Symbol
pub fn effect_kind(&self) -> &Symbol
Returns the effect kind the open performs.
Sourcepub fn requires(&self) -> &[CapabilityName]
pub fn requires(&self) -> &[CapabilityName]
Returns the capabilities the open requires.