pub struct HostOpenStream { /* private fields */ }Expand description
Open stream plus host-side callback queue.
Implementations
Sourceimpl HostOpenStream
impl HostOpenStream
Sourcepub fn new(config: HostStreamConfig) -> Self
pub fn new(config: HostStreamConfig) -> Self
Creates an opened host stream backed by a push stream value.
Sourcepub fn new_with_driver(
config: HostStreamConfig,
driver: Rc<dyn HostStreamDriver>,
) -> Self
pub fn new_with_driver( config: HostStreamConfig, driver: Rc<dyn HostStreamDriver>, ) -> Self
Creates an opened host stream with an attached external driver.
Sourcepub fn try_new_with_driver(
config: HostStreamConfig,
build_driver: impl FnOnce(HostCallbackQueue) -> Result<Rc<dyn HostStreamDriver>>,
) -> Result<Self>
pub fn try_new_with_driver( config: HostStreamConfig, build_driver: impl FnOnce(HostCallbackQueue) -> Result<Rc<dyn HostStreamDriver>>, ) -> Result<Self>
Creates an opened host stream by building its driver from the callback queue that will be stored on the stream.
Sourcepub fn new_realtime_local_audio(config: HostStreamConfig) -> Result<Self>
pub fn new_realtime_local_audio(config: HostStreamConfig) -> Result<Self>
Creates a realtime local audio stream after validating callback limits.
Sourcepub fn new_realtime_local_audio_with_driver(
config: HostStreamConfig,
driver: Rc<dyn HostStreamDriver>,
) -> Result<Self>
pub fn new_realtime_local_audio_with_driver( config: HostStreamConfig, driver: Rc<dyn HostStreamDriver>, ) -> Result<Self>
Creates a realtime local audio stream with an attached external driver.
Sourcepub fn try_new_realtime_local_audio_with_driver(
config: HostStreamConfig,
build_driver: impl FnOnce(HostCallbackQueue) -> Result<Rc<dyn HostStreamDriver>>,
) -> Result<Self>
pub fn try_new_realtime_local_audio_with_driver( config: HostStreamConfig, build_driver: impl FnOnce(HostCallbackQueue) -> Result<Rc<dyn HostStreamDriver>>, ) -> Result<Self>
Creates a realtime local audio stream by building its driver from the stored callback queue.
Sourcepub fn new_lan_midi_control(config: HostStreamConfig) -> Result<Self>
pub fn new_lan_midi_control(config: HostStreamConfig) -> Result<Self>
Creates a LAN MIDI/control stream after validating media and clock shape.
Sourcepub fn new_lan_buffered_audio_preview(config: HostStreamConfig) -> Result<Self>
pub fn new_lan_buffered_audio_preview(config: HostStreamConfig) -> Result<Self>
Creates a LAN buffered audio preview stream after validating media shape.
Sourcepub fn config(&self) -> &HostStreamConfig
pub fn config(&self) -> &HostStreamConfig
Returns the accepted stream configuration.
Sourcepub fn queue(&self) -> &HostCallbackQueue
pub fn queue(&self) -> &HostCallbackQueue
Returns the callback queue used by host callbacks or deterministic fakes.
Sourcepub fn stream(&self) -> Arc<StreamValue>
pub fn stream(&self) -> Arc<StreamValue>
Returns the stream value consumed by graph/runtime code.