pub struct MidiLiveEvalSite { /* private fields */ }Expand description
Live MIDI evaluation site opened from a cataloged device record.
Implementations
Sourceimpl MidiLiveEvalSite
impl MidiLiveEvalSite
Sourcepub fn from_eval_site(
id: &Symbol,
site: Box<dyn StreamEvalSite>,
) -> Result<Self>
pub fn from_eval_site( id: &Symbol, site: Box<dyn StreamEvalSite>, ) -> Result<Self>
Wraps an opened catalog site in a live MIDI session.
Sourcepub fn source_mut(&mut self) -> &mut dyn MidiSource<Err = Infallible>
pub fn source_mut(&mut self) -> &mut dyn MidiSource<Err = Infallible>
Returns the live MIDI source side.
Sourcepub fn sink_mut(&mut self) -> Option<&mut dyn MidiSink<Err = Infallible>>
pub fn sink_mut(&mut self) -> Option<&mut dyn MidiSink<Err = Infallible>>
Returns the live MIDI sink side when this site supports output.